@@ -380,6 +380,7 @@ Run `doric-themes-after-load-theme-hook' after loading a theme."
     company-tooltip-scrollbar-track
     consult-preview-line
     corfu-popupinfo
+    edebug-enabled-breakpoint
     ediff-even-diff-A
     ediff-even-diff-Ancestor
     ediff-even-diff-B
@@ -490,6 +491,7 @@ Run `doric-themes-after-load-theme-hook' after loading a theme."
     diredfl-read-priv
     diredfl-tagged-autofile-name
     diredfl-write-priv
+    edebug-disabled-breakpoint
     elfeed-search-title-face
     epa-validity-disabled
     eshell-ls-unreadable
@@ -1241,7 +1243,8 @@ Run `doric-themes-after-load-theme-hook' after loading a theme."
 (defconst doric-themes-error-foreground-only-faces
   '(TeX-error-description-error
     dired-broken-symlink
-    error))
+    error
+    ert-test-result-unexpected))
 
 (defconst doric-themes-warning-foreground-only-faces
   '(TeX-error-description-warning
@@ -1253,6 +1256,7 @@ Run `doric-themes-after-load-theme-hook' after loading a theme."
 (defconst doric-themes-success-foreground-only-faces
   '(TeX-error-description-help
     TeX-error-description-tex-said
+    ert-test-result-expected
     success))
 
 (defconst doric-themes-error-underline-faces
